@@ -9,7 +9,7 @@
 """
 Utilities to provide essential data items for chemical component definitions.
 """
-__docformat__ = "google.en"
+__docformat__ = "google en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
